@@ -66,10 +66,11 @@ class Connection(object):
         The ``btrdb.connect`` method is a helper function to make connecting to the platform easier
             usually that will be sufficient for most users.
         """
+        # 4 Is a magic number to make sure the error propagates where btrdb.connect is called.
         warn(
             "This API is deprecated in favor of the pingthings_api, refer to your hub landing page for further documentation.",
-            DeprecationWarning,
-            stacklevel=2,
+            FutureWarning,
+            stacklevel=4,
         )
         addrport = addrportstr.split(":", 2)
         # 100MB size limit ~ 2500 streams for 5000 points with each point being 64bit
@@ -135,7 +136,7 @@ class Connection(object):
                         version = "unknown"
                         try:
                             version = importlib.metadata.version("btrdb")
-                        except:
+                        except Exception:
                             pass
                         metadata.append(
                             (
