@@ -16,10 +16,11 @@ Package for interacting with the PredictiveGrid credentials file.
 ##########################################################################
 
 import os
-import yaml
 from functools import wraps
 
-from btrdb.exceptions import ProfileNotFound, CredentialsFileNotFound
+import yaml
+
+from btrdb.exceptions import CredentialsFileNotFound, ProfileNotFound
 
 ##########################################################################
 ## Module Variables
@@ -27,21 +28,27 @@ from btrdb.exceptions import ProfileNotFound, CredentialsFileNotFound
 
 CONFIG_DIR = ".predictivegrid"
 CREDENTIALS_FILENAME = "credentials.yaml"
-CREDENTIALS_PATH = os.path.join(os.path.expanduser("~"), CONFIG_DIR, CREDENTIALS_FILENAME)
+CREDENTIALS_PATH = os.path.join(
+    os.path.expanduser("~"), CONFIG_DIR, CREDENTIALS_FILENAME
+)
 
 ##########################################################################
 ## Functions
 ##########################################################################
 
+
 def filter_none(f):
     """
     decorator for removing dict items with None as value
     """
+
     @wraps(f)
     def inner(*args, **kwargs):
-        return  { k: v for k, v in f(*args, **kwargs).items() if v is not None }
+        return {k: v for k, v in f(*args, **kwargs).items() if v is not None}
+
     return inner
 
+
 def load_credentials_from_file():
     """
     Returns a dict of the credentials file contents
@@ -52,10 +59,13 @@ def load_credentials_from_file():
         A dictionary of profile connection information
     """
     try:
-        with open(CREDENTIALS_PATH, 'r') as stream:
+        with open(CREDENTIALS_PATH, "r") as stream:
             return yaml.safe_load(stream)
     except FileNotFoundError as exc:
-        raise CredentialsFileNotFound("Cound not find `{}`".format(CREDENTIALS_PATH)) from exc
+        raise CredentialsFileNotFound(
+            "Cound not find `{}`".format(CREDENTIALS_PATH)
+        ) from exc
+
 
 @filter_none
 def credentials_by_profile(name=None):
@@ -82,14 +92,16 @@ def credentials_by_profile(name=None):
         The requested profile could not be found in the credentials file
     """
     if not name:
-        name = os.environ.get("BTRDB_PROFILE", 'default')
+        name = os.environ.get("BTRDB_PROFILE", "default")
 
     # load from credentials yaml file
     creds = load_credentials_from_file()
     if name not in creds.keys():
-        if name == 'default':
+        if name == "default":
             return {}
-        raise ProfileNotFound("Profile `{}` not found in credentials file.".format(name))
+        raise ProfileNotFound(
+            "Profile `{}` not found in credentials file.".format(name)
+        )
 
     # rename api_key if needed and return
     fragment = creds[name].get("btrdb", {})
@@ -97,6 +109,7 @@ def credentials_by_profile(name=None):
         fragment["apikey"] = fragment.pop("api_key")
     return fragment
 
+
 @filter_none
 def credentials_by_env():
     """
@@ -110,7 +123,7 @@ def credentials_by_env():
     """
     return {
         "endpoints": os.environ.get("BTRDB_ENDPOINTS", None),
-        "apikey": os.environ.get("BTRDB_API_KEY",  None),
+        "apikey": os.environ.get("BTRDB_API_KEY", None),
     }
 
 
@@ -131,7 +144,12 @@ def credentials(endpoints=None, apikey=None):
 
     """
     creds = {}
-    credentials_by_arg = filter_none(lambda: { "endpoints": endpoints, "apikey": apikey, })
+    credentials_by_arg = filter_none(
+        lambda: {
+            "endpoints": endpoints,
+            "apikey": apikey,
+        }
+    )
     pipeline = [credentials_by_env, credentials_by_arg]
     if os.path.exists(CREDENTIALS_PATH):
         pipeline.insert(0, credentials_by_profile)
